@@ -19,6 +19,7 @@
 #define EVENT_DATE_H
 
 #include <gtkmm.h>
+#include <time.h>
 
 class EventDateRegion;
 
@@ -28,6 +29,8 @@ class EventDate
 
         EventDate();
 
+        EventDate(time_t point);
+
 	//! Copy constructor.
         EventDate(const EventDate& orig);
 
