@@ -31,3 +31,8 @@ HostListLoader::~HostListLoader()
 void HostListLoader::reload()
 {
 }
+
+Gdk::Color HostListLoader::genre_to_colour(std::string genre)
+{
+  return Gdk::Color("black");
+}
